diff --git a/sammy/src/int/mint4.f b/sammy/src/int/mint4.f
index 5726c87e4aaca502030e14fe211b9b2d9d5a0b24..905a6dab8639562f01e1d1d5bab650978e119af0 100644
--- a/sammy/src/int/mint4.f
+++ b/sammy/src/int/mint4.f
@@ -22,7 +22,7 @@ C
 C
 C For now assume only one grid
       call expData%getGrid(grid, 1)
-      ipos = grid%getDataIndex()
+      ipos = grid%getDataColumn()
       idat = grid%getLength()
       Do I = 1, idat
          Data(I) = grid%getData(I, ipos)
diff --git a/sammy/src/mso/mmso2.f b/sammy/src/mso/mmso2.f
index 13055bdc26ba454c1679c6b3d614a286c7d75dde..277cfd28cc5c55eab8c7d5ac27a37851cfb3f029 100644
--- a/sammy/src/mso/mmso2.f
+++ b/sammy/src/mso/mmso2.f
@@ -142,9 +142,12 @@ C
      *      Dy2ccc(1,n), Dy2bbb, Dy2bbq, Dy2bqq, Y0, Yyy1, Yyy1fb,
      *      Yyy2, Yyy2q, Y2bbbb, Y2bbbq, Nx)
 C
+          ksolve_save = ksolve
+          ksolve = 0  ! ensure that Dddlll is always zeroed out for the 7 version
          CALL Getcrs(Ccclll, Dddlll, Isopar, Vsigxx, Vdasig, Vdbsig,
      *      Totsig, Capsig, Dtotsi, Dcapsi, Ee, Elastic,
      *      Nx, Nn, Istop)
+         ksolve = ksolve_save
          IF (Istop.EQ.1) GO TO 80
 C
 C ***    get Energy Em
diff --git a/sammy/src/npv/mnpv5.f b/sammy/src/npv/mnpv5.f
index 00a2f576a39bd4b8c740ba61772d9489dd444719..01c9066da0c5054f3ba1d51589cefd43ebae824d 100755
--- a/sammy/src/npv/mnpv5.f
+++ b/sammy/src/npv/mnpv5.f
@@ -15,7 +15,7 @@ C For now assume one grid
 C
       call expData%getGrid(grid, 1)
       idat = grid%getLength()
-      ipos = grid%getDataIndex()
+      ipos = grid%getDataColumn()
       ivar = 1
       Do I = 1, idat
          Data(I) = grid%getData(I, ipos)
diff --git a/sammy/src/odf/modf3.f90 b/sammy/src/odf/modf3.f90
index 9d0f097818e9f7fc7001b4d248443a78dcad4622..0f47887a1f9ff5efc48aa4849ed082fcc9100f85 100755
--- a/sammy/src/odf/modf3.f90
+++ b/sammy/src/odf/modf3.f90
@@ -94,7 +94,7 @@ contains
       IMPLICIT NONE
       INTEGER*4 Iu, Ifb, Ins, Mode, Strt, Isc, Inc, N, Narray, Min, Max,   &
          Iscx, Incx, J, K, I
-      REAL*4 Arrayx(1024), Zero
+      REAL*4 Arrayx(1024), Zero        ! 1024 is the block size of the ODF file
       DATA Narray /1024/, Zero /0.0/
 !
       Ifb = Ifb_Plt
@@ -134,7 +134,7 @@ contains
          Narray, Min, Max, Insx, Isnx, Iscx, Incx, Indexx, J, K, I,   &
          Iux
       DOUBLE PRECISION Array(Index,*)
-      REAL*4 Arrayx(1024)
+      REAL*4 Arrayx(1024)       ! 1024 is the block size of the ODF file
       procedure (arrayFunc), pointer :: f_ptr
       optional f_ptr
       DATA Narray /1024/
@@ -194,7 +194,7 @@ contains
       INTEGER*4 Iu, Ifb, Ins, Isn, Mode, Strt, Isc, Inc, Index, N,   &
          Narray, Min, Max, Iscx, Incx, J, K, I, Iux
       DOUBLE PRECISION Array(Index,*)
-      REAL*4 Arrayx(1024)
+      REAL*4 Arrayx(1024)   ! 1024 is the block size of the ODF file
       DATA Narray /1024/
 !
       IF (Iux.LT.0) THEN
diff --git a/sammy/src/ref/mref0.f b/sammy/src/ref/mref0.f
index c06a67b28f2501ba498bf0f7b178f2f0bf899de3..7e5b5a8184205b72dde14b4320ff34af5c124aba 100644
--- a/sammy/src/ref/mref0.f
+++ b/sammy/src/ref/mref0.f
@@ -79,7 +79,7 @@ C
 C For now assume only one grid
 C
       call expData%getGrid(grid, 1)
-      ipos = grid%getDataIndex()
+      ipos = grid%getDataColumn()
       do I = 1, grid%getLength()
           Data(I) =  grid%getData(I, ipos)
           val =  expData%getExperimentalCov(I, I)
diff --git a/sammy/src/salmon/GridData.cpp b/sammy/src/salmon/GridData.cpp
index 4c06a8da33892c5f59f1e5e5b36dead99c172b24..8f802af0b7af7ee7eb7fea64217179b5015b6421 100644
--- a/sammy/src/salmon/GridData.cpp
+++ b/sammy/src/salmon/GridData.cpp
@@ -30,7 +30,7 @@ namespace sammy{
          return data[row][col];
      }
 
-     int GridData::getDataIndex() const{
+     int GridData::getDataColumn() const{
          return dataIndex;
      }
 
diff --git a/sammy/src/salmon/interface/cix/GridData.cpp2f.xml b/sammy/src/salmon/interface/cix/GridData.cpp2f.xml
index f2deb88c4a656f9415e212ef5f3616c86ac75c57..7bf3b547c479d90f7caaa10f1a4a20c0fd6e82f4 100644
--- a/sammy/src/salmon/interface/cix/GridData.cpp2f.xml
+++ b/sammy/src/salmon/interface/cix/GridData.cpp2f.xml
@@ -13,7 +13,7 @@
          <param name="row" type="int" offset="-1"/>
          <param name="col" type="int" offset="-1"/>
       </method>
-      <method name="getDataIndex" return_type="int"/>
+      <method name="getDataColumn" return_type="int"/>
       <method name="setDataIndex">
          <param name="ind" type="int" offset="-1"/>
       </method>
diff --git a/sammy/src/salmon/interface/cpp/GridDataInterface.cpp b/sammy/src/salmon/interface/cpp/GridDataInterface.cpp
index deccf9de0be34e1e3a7656139d4e90220aa703e4..ae551264b97905203c241a292cccac9c07587628 100644
--- a/sammy/src/salmon/interface/cpp/GridDataInterface.cpp
+++ b/sammy/src/salmon/interface/cpp/GridDataInterface.cpp
@@ -24,9 +24,9 @@ double GridData_getData(void * GridData_ptr,int * row,int * col)
     return ((GridData*)GridData_ptr)->getData(*row,*col);
 }
 
-int GridData_getDataIndex(void * GridData_ptr)
+int GridData_getDataColumn(void * GridData_ptr)
 {
-    return ((GridData*)GridData_ptr)->getDataIndex();
+    return ((GridData*)GridData_ptr)->getDataColumn();
 }
 
 void GridData_setDataIndex(void * GridData_ptr,int * ind)
diff --git a/sammy/src/salmon/interface/cpp/GridDataInterface.h b/sammy/src/salmon/interface/cpp/GridDataInterface.h
index f9fe2f4fd2940b9e2bc2586dd026215c71f91d1c..f53743149221ae6d5779cb119fc14425ab7ccac3 100644
--- a/sammy/src/salmon/interface/cpp/GridDataInterface.h
+++ b/sammy/src/salmon/interface/cpp/GridDataInterface.h
@@ -16,7 +16,7 @@ extern "C" {
 int GridData_getLength(void * GridData_ptr);
 void GridData_addData(void * GridData_ptr,int * row,int * col,double * val);
 double GridData_getData(void * GridData_ptr,int * row,int * col);
-int GridData_getDataIndex(void * GridData_ptr);
+int GridData_getDataColumn(void * GridData_ptr);
 void GridData_setDataIndex(void * GridData_ptr,int * ind);
 int GridData_getRowOffset(void * GridData_ptr);
 void GridData_setRowOffset(void * GridData_ptr,int * offset);
diff --git a/sammy/src/salmon/interface/fortran/GridData_I.f90 b/sammy/src/salmon/interface/fortran/GridData_I.f90
index a7aa27636d24592f2d06a0feb4dae69fcc166520..eb41de000d6636361522c329cb24e2267ec2e493 100644
--- a/sammy/src/salmon/interface/fortran/GridData_I.f90
+++ b/sammy/src/salmon/interface/fortran/GridData_I.f90
@@ -29,7 +29,7 @@ real(C_DOUBLE) function f_GridData_getData(GridData_ptr, row,col ) BIND(C,name="
     integer(C_INT) :: row;
     integer(C_INT) :: col;
 end function
-integer(C_INT) function f_GridData_getDataIndex(GridData_ptr ) BIND(C,name="GridData_getDataIndex")
+integer(C_INT) function f_GridData_getDataColumn(GridData_ptr ) BIND(C,name="GridData_getDataColumn")
     use,intrinsic :: ISO_C_BINDING
     implicit none
     type(C_PTR), value :: GridData_ptr;
diff --git a/sammy/src/salmon/interface/fortran/GridData_M.f90 b/sammy/src/salmon/interface/fortran/GridData_M.f90
index 01456139d5ab98a88a29a0a0f51aa52192ede7c3..60c44341a6518f42a0389273cad34ec92bd66a5c 100644
--- a/sammy/src/salmon/interface/fortran/GridData_M.f90
+++ b/sammy/src/salmon/interface/fortran/GridData_M.f90
@@ -15,7 +15,7 @@ type GridData
     procedure, pass(this) :: getLength => GridData_getLength
     procedure, pass(this) :: addData => GridData_addData
     procedure, pass(this) :: getData => GridData_getData
-    procedure, pass(this) :: getDataIndex => GridData_getDataIndex
+    procedure, pass(this) :: getDataColumn => GridData_getDataColumn
     procedure, pass(this) :: setDataIndex => GridData_setDataIndex
     procedure, pass(this) :: getRowOffset => GridData_getRowOffset
     procedure, pass(this) :: setRowOffset => GridData_setRowOffset
@@ -61,11 +61,11 @@ function GridData_getData(this, row, col) result(result2Return)
     real(C_DOUBLE):: result2Return
     result2Return=f_GridData_getData(this%instance_ptr, row-1,col-1)
 end function
-function GridData_getDataIndex(this) result(result2Return)
+function GridData_getDataColumn(this) result(result2Return)
     implicit none
     class(GridData)::this
     integer(C_INT):: result2Return
-    result2Return=f_GridData_getDataIndex(this%instance_ptr) + 1
+    result2Return=f_GridData_getDataColumn(this%instance_ptr) + 1
 end function
 subroutine GridData_setDataIndex(this, ind)
     implicit none
diff --git a/sammy/src/salmon/tests/GridDataTest.cpp b/sammy/src/salmon/tests/GridDataTest.cpp
index ffdbbd9d9c4b0b89d71726eea084b3ad7c6d48ff..6074d933594d952504dd54a27534bdfd6412fa38 100644
--- a/sammy/src/salmon/tests/GridDataTest.cpp
+++ b/sammy/src/salmon/tests/GridDataTest.cpp
@@ -60,7 +60,7 @@ TEST(GridDataSetter,gridData){
 TEST(DataInfo,gridData){
    sammy::GridData grid;
 
-   ASSERT_EQ(-1, grid.getDataIndex());
+   ASSERT_EQ(-1, grid.getDataColumn());
    ASSERT_EQ(0, grid.getRowOffset());
 
    grid.setDataIndex(6);
@@ -73,12 +73,12 @@ TEST(DataInfo,gridData){
        }
    }
 
-   ASSERT_EQ(6, grid.getDataIndex());
+   ASSERT_EQ(6, grid.getDataColumn());
    ASSERT_EQ(9, grid.getRowOffset());
 
    // copy constructor
    sammy::GridData gridCopy(grid);
-   ASSERT_EQ(6, gridCopy.getDataIndex());
+   ASSERT_EQ(6, gridCopy.getDataColumn());
    ASSERT_EQ(9, gridCopy.getRowOffset());
    xx = 1.0;
    for (int i = 0; i < 5; i++){
diff --git a/sammy/src/ssm/mssm04.f90 b/sammy/src/ssm/mssm04.f90
index 4fe66397c9e0c6d08d5a87299448667369bfe3b7..8c3a41fcaa1b7063435806b8fb2d7dd4a89af970 100644
--- a/sammy/src/ssm/mssm04.f90
+++ b/sammy/src/ssm/mssm04.f90
@@ -83,7 +83,7 @@ module ssm_4_m
 ! ***       Here if Idone=3, which means don't calculate yield, but do
 ! ***          calculate the pieces needed for Y2
 !
-! ***       Also here if Idone=0,  Em is bigger than Eminr, so
+! ***       Also here if Idone=0,  energy Em is bigger than Eminr, so
 ! ***          calculation can proceed
 !
             IF (Idone.NE.3 .AND. Kdatmn.EQ.0) Kdatmn = Nn
diff --git a/sammy/src/the/mthe1.f b/sammy/src/the/mthe1.f
index 4fc457ebae233557161283b9758ee2ef21349cdc..758104af86c436ab2c3b018d37b1525169779c0e 100644
--- a/sammy/src/the/mthe1.f
+++ b/sammy/src/the/mthe1.f
@@ -193,7 +193,7 @@ C
       IF (Nfpres.GT.0) THEN
 C
          call expData%getGrid(grid, 1)
-         ipos = grid%getDataIndex()
+         ipos = grid%getDataColumn()
          idat = grid%getLength()
          do J = 1, Ndat
             Dum(I) = grid%getData(K, ipos)
diff --git a/sammy/src/salmon/GridData.h b/sammy/src/salmon/GridData.h
index 9fd75f36c4fb0f6b13fde7847dba2e1322360cff..13dd2b3378849381b47064444b723c59dbce9dc5 100644
--- a/sammy/src/salmon/GridData.h
+++ b/sammy/src/salmon/GridData.h
@@ -19,7 +19,7 @@ namespace sammy{
    * In this case energy points for each angle are repeated  (as SAMMY requires all angle data to be on the
    * same energy grid).  But we want to relax that going forward.
    *
    * To indicate where the data start, the grid has a function (getDataIndex) to indicate the data column
    *
    * Sometimes we may want to store more energy data then are used for the calculation, for example extra data points being read
    * in or points of the auxillary grid not used, therefore we allow for an offset, that indicates from where counting of
@@ -62,10 +62,10 @@ namespace sammy{
       double getData(int row, int col) const;
 
       /**
        * @brief getDataIndex Get the index at which the data start
        * @return  index at which the data start
        */
-      int getDataIndex() const;
+      int getDataColumn() const;
 
       /**
        * @brief setDataIndex set the index at which the data start
@@ -19,7 +19,7 @@ namespace sammy{
    * same energy grid).  But we want to relax that going forward.
    *
-   * To indicate where the data start, the grid has a function (getDataIndex) to indicate the data column
+   * To indicate where the data start, the grid has a function (getDataColumn) to indicate the data column
    *
    * Sometimes we may want to store more energy data then are used for the calculation, for example extra data points being read
@@ -62,10 +62,10 @@ namespace sammy{
 
       /**
-       * @brief getDataIndex Get the index at which the data start
+       * @brief getDataColumn Get the index at which the data start
        * @return  index at which the data start
        */